/*
 * @(#) HeuristicRollback.java
 *
 * JOTM: Java Open Transaction Manager
 *
 *
 * This module was originally developed by
 *
 *  - Bull S.A. as part of the JOnAS application server code released in
 *    July 1999 (www.bull.com)
 *
 * --------------------------------------------------------------------------
 *  The original code and portions created by Bull SA are
 *  Copyright (c) 1999 BULL SA
 *  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * -Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * -Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * --------------------------------------------------------------------------
 * $Id: HeuristicRollback.java 1156 2011-06-08 13:58:41Z benoitf $
 * --------------------------------------------------------------------------
 */



package org.objectweb.jotm.rmi;


/**
 * Utility class for rmi/iiop exceptions management
 *
 * @author Benoit Pelletier
 */

public class RmiIIOPUtility {

    /**
     * private constructor mandatory for utilities class
     *
     */
    private RmiIIOPUtility() {
    }

    /**
     * Map a java exception to a corba exception
     *
     * @param e exception to process
     */
    public static void rethrowCorbaException(Exception e) {


        if (e instanceof java.rmi.MarshalException) {
            throw new org.omg.CORBA.MARSHAL(e.toString());
        } else if (e instanceof java.rmi.NoSuchObjectException) {
            throw new org.omg.CORBA.OBJECT_NOT_EXIST(e.toString());
        } else if (e instanceof java.rmi.AccessException) {
            throw new org.omg.CORBA.NO_PERMISSION(e.toString());
        } else if (e instanceof javax.transaction.TransactionRequiredException) {
            throw new org.omg.CORBA.TRANSACTION_REQUIRED(e.toString());
        } else if (e instanceof javax.transaction.TransactionRolledbackException) {
            throw new org.omg.CORBA.TRANSACTION_ROLLEDBACK(e.toString());
        } else if (e instanceof javax.transaction.InvalidTransactionException) {
            throw new org.omg.CORBA.INVALID_TRANSACTION(e.toString());
        }
    }
}
